@@ -30,9 +30,16 @@
 ##' \code{bake} and \code{stew} also store information about the code executed, the dependencies, and the state of the random-number generator (if the latter is controlled) in the archive file.
 ##' Re-computation is triggered if any of these things change.
 ##'
-##' @param file Name of the binary data file in which the result will be stored or retrieved, as appropriate.
+##' @section Avoid using \sQuote{pomp} objects as dependencies:
+##' Note that when a \sQuote{pomp} object is built with one or more \link[=Csnippet]{C snippets}, the resulting code is \dQuote{salted} with a random element to prevent collisions in parallel computations.
+##' As a result, two such \sQuote{pomp} objects will never match perfectly, even if the codes and data used to construct them are identical.
+##' Therefore, avoid using \sQuote{pomp} objects as dependencies in \code{bake} and \code{stew}.
+##'
+##' @param file Name of the archive file in which the result will be stored or retrieved, as appropriate.
 ##' For \code{bake}, this will contain a single object and hence be an RDS file (extension \sQuote{rds});
 ##' for \code{stew}, this will contain one or more named objects and hence be an RDA file (extension \sQuote{rda}).
+##' @param dir Directory holding archive files; by default, this is the current working directory.
+##' This can also be set using the global option \code{pomp_archive_dir}.
 ##' @param expr Expression to be evaluated.
 ##' @param seed,kind,normal.kind optional.
 ##' To set the state and of the RNG.
@@ -46,6 +53,7 @@
 ##' recomputation is forced when these do not match.
 ##' The dependencies should be specified as unquoted symbols:
 ##' use a list if there are multiple dependencies.
+##' See the note below about avoiding using \sQuote{pomp} objects as dependencies.
 ##' @param timing logical.
 ##' If \code{TRUE}, the time required for the computation is returned.
 ##' This is returned as the \dQuote{system.time} attribute of the returned object.
@@ -89,6 +97,13 @@
 ##'
 NULL
 
+##' @importFrom digest digest
+code_digest <- function (expr) {
+  digest(deparse(expr,
+    control=c("keepInteger","quoteExpressions","showAttributes",
+      "keepNA","niceNames","delayPromises","hexNumeric")))
+}
+
 process_dependencies <- function (dependson, envir, ep)
 {
   tryCatch(
@@ -134,15 +149,15 @@ update_bake_archive <- function (val, code, deps, file) {
 }
 
 ##' @rdname bake
-##' @importFrom digest digest    
 ##' @export
 bake <- function (
   file, expr,
   seed = NULL, kind = NULL, normal.kind = NULL,
-  dependson = NULL, info = FALSE, timing = TRUE
+  dependson = NULL, info = FALSE, timing = TRUE,
+  dir = getOption("pomp_archive_dir",getwd())
 ) {
   expr <- substitute(expr)
-  code <- digest(deparse(expr,control="all"))
+  code <- code_digest(expr)
   deps <- process_dependencies(
     dependson=substitute(dependson),
     envir=parent.frame(),
@@ -150,6 +165,7 @@ bake <- function (
   )
   info <- as.logical(info)
   timing <- as.logical(timing)
+  file <- file.path(as.character(dir[[1L]]),as.character(file))
   reload <- file.exists(file)
   if (reload) {
     val <- readRDS(file)
@@ -224,16 +240,18 @@ update_stew_archive <- function (
 stew <- function (
   file, expr,
   seed = NULL, kind = NULL, normal.kind = NULL,
-  dependson = NULL, info = FALSE
+  dependson = NULL, info = FALSE,
+  dir = getOption("pomp_archive_dir",getwd())
 ) {
   expr <- substitute(expr)
-  code <- digest(deparse(expr,control="all"))
+  code <- code_digest(expr)
   deps <- process_dependencies(
     dependson=substitute(dependson),
     envir=parent.frame(),
     ep="stew"
   )
   info <- as.logical(info)
+  file <- file.path(as.character(dir[[1L]]),as.character(file))
   reload <- file.exists(file)
   e <- new.env()
   if (reload) {
