@@ -7,6 +7,7 @@
 ##' @rdname obs
 ##' @include pomp_class.R
 ##' @importFrom stats setNames
+##' @family extraction methods
 ##'
 NULL
 
@@ -36,3 +37,13 @@ setMethod(
     y
   }
 )
+
+##' @rdname obs
+##' @export
+setMethod(
+  "obs",
+  signature=signature(object="listie"),
+  definition=function (object, vars, ...) {
+    lapply(object,obs)
+  }
+)
