@@ -26,6 +26,7 @@
 ##' @param N_0 initial condition
 ##'
 ##' @example examples/ricker.R
+##' @example examples/ricker-bifdiag.R
 ##'
 NULL
 
@@ -101,6 +102,10 @@ ricker <- function (r = exp(3.8), sigma = 0.3, phi = 10, c = 1,
       N = exp(log(r)+log(N)-c*N+e);"),
       delta.t=1
     ),
+    emeasure=Csnippet("
+    E_y = phi*N;"),
+    vmeasure=Csnippet("
+    V_y_y = phi*N;"),
     rmeasure=Csnippet("
     y = rpois(phi*N);"),
     dmeasure=Csnippet("
